@@ -476,9 +476,10 @@ class Distributive(object):
         """
         newDirectoryName = directory
         for i in range(2, 9999):
-            if not path.exists(newDirectoryName):
+            try:
+                os.mkdir(newDirectoryName)
                 return newDirectoryName
-            else:
+            except OSError:
                 newDirectoryName = "%s.%02d" % (directory, i)
         return newDirectoryName
 
